==> ktp-text-ui-19.04.0.tar.xz: ktp-text-ui-19.04.0/filters/youtube/ktptextui_message_filter_youtube.desktop.cmake <==
[Desktop Entry]
Name=YouTube Preview
Name[ar]=معاينة يوتيوب
Name[bs]=YouTube pregled
Name[ca]=Vista prèvia de YouTube
Name[ca@valencia]=Vista prèvia de YouTube
Name[cs]=Náhled YouTube
Name[da]=Forhåndsvisning af YouTube
Name[de]=YouTube-Vorschau
Name[el]=Προεπισκόπηση YouTube
Name[en_GB]=YouTube Preview
Name[es]=Vista previa de YouTube
Name[et]=Youtube'i eelvaatlus
Name[fi]=YouTube-esikatselu
Name[fr]=Miniature YouTube
Name[gl]=Vista previa de YouTube
Name[hu]=YouTube előnézet
Name[ia]=Vista preliminar de YouTube
Name[it]=Anteprima di YouTube
Name[kk]=YouTube алдың-аласы
Name[ko]=YouTube 미리 보기
Name[lt]=YouTube peržiūra
Name[mr]=यूट्यूब पूर्वावलोकन
Name[nb]=YouTube forhåndsvisning
Name[nds]=YouTube-Vöransicht
Name[nl]=Voorbeeld van YouTube
Name[nn]=Førehandsvising av YouTube
Name[pa]=ਯੂਟਿਊਬ ਝਲਕ
Name[pl]=Podgląd YouTube
Name[pt]=Antevisão do YouTube
Name[pt_BR]=Visualização do YouTube
Name[ro]=Previzualizare YouTube
Name[ru]=Просмотр видео с YouTube
Name[sk]=Náhľad YouTube
Name[sl]=Predogled YouTube
Name[sr]=Преглед са Јутјуба
Name[sr@ijekavian]=Преглед са Јутјуба
Name[sr@ijekavianlatin]=Pregled sa YouTubea
Name[sr@latin]=Pregled sa YouTubea
Name[sv]=Förhandsgranskning av YouTube
Name[tr]=YouTube Önizlemesi
Name[uk]=Попередній перегляд YouTube
Name[x-test]=xxYouTube Previewxx
Name[zh_CN]=YouTube 预览
Name[zh_TW]=YouTube 預覽
Comment=If any messages contains a link to a YouTube video, it will embed a preview in the chat
Comment[ar]=إن احتوت أيّ رسالة وصلة إلى فيديو يوتيوب، ستُضمّن معاينة في الدّردشة.
Comment[bs]=Ako poruka sadrži vezu na YouTube video, oma će se ugraditi u pregled ćaskanja
Comment[ca]=Si qualsevol missatge conté un enllaç a un vídeo de YouTube, s'incrustarà una vista prèvia en el xat
Comment[ca@valencia]=Si qualsevol missatge conté un enllaç a un vídeo de YouTube, s'incrustarà una vista prèvia en el xat
Comment[cs]=Pokud zpráva obsahuje odkaz na video YouTube bude vložen jeho náhled do rozhovoru
Comment[da]=If beskeder indeholder et link til en YouTube-video vil en forhåndsvisning blive indlejret i chatten
Comment[de]=Wenn eine Nachricht eine Verknüpfung zu einem YouTube-Video enthält, wird das Video als Vorschau im Chat-Fenster angezeigt
Comment[el]=Στα μηνύματα που περιέχουν σύνδεσμο σε YouTube βίντεο, θα ενσωματώνεται η προεπισκόπηση στη συνομιλία
Comment[en_GB]=If any messages contains a link to a YouTube video, it will embed a preview in the chat
Comment[es]=Si un mensaje contiene un enlace a un vídeo de YouTube, esta opción incrustará una vista previa en la conversación.
Comment[et]=Kui sisenev sõnum sisaldab Youtube'i video linki, põimitakse selle eelvaatlus vestlusse
Comment[fi]=Jos saapuvassa viestissä on linkki YouTube-videoon, keskusteluun upotetaan esikatselu videosta
Comment[fr]=Si un quelconque message contient un lien vers une vidéo YouTube, il intégrera une miniature dans la conversation
Comment[gl]=Se algunha mensaxe contén unha ligazón a un vídeo en YouTube ha incluír unha vista previa na conversa
Comment[hu]=Ha egy üzenet hivatkozást tartalmaz egy YouTube videóra, akkor az előnézet be lesz ágyazva a csevegésbe
Comment[ia]=Si qualcunque messages contine un ligamine a tu video de YouTube, illlo incorporara un vista preliminar in le conversation.
Comment[it]=Se in un messaggio c'è un collegamento ad un video di YouTube, sarà integrato come anteprima nella finestra di chat
Comment[kk]=Егер хабарламада YouTube видеосына сілтеме болса, оның қарап-шығу мүмкіндігі чатта болады
Comment[ko]=YouTube 동영상 링크를 포함하는 경우 대화 창에 미리 보기를 표시
Comment[lt]=Jei bet kuri žinutė turi nuorodą į YouTube vaizdo įrašą, bus įterpta peržiūra pokalbyje
Comment[nb]=Hvis en melding inneholder en lenke til en YouTube-video, så blir en forhåndsvisning av videoen bygget inn i praten
Comment[nds]=För elkeen binnen en Naricht vörhannen Link op en YouTube-Video en Vöransicht inbetten
Comment[nl]=Als een bericht een koppeling bevat naar een YouTube video, zal het ingebed worden als een voorbeeld in de chat
Comment[nn]=Viss ei melding inneheld ei lenkje til ein YouTube-video, vert ei førehandsvising innebygd i praten
Comment[pl]=Jeśli jakakolwiek wiadomość zawiera odnośnik do filmu na YouTube, to zostanie osadzony jej podgląd w oknie rozmowy
Comment[pt]=Se alguma das mensagens tiver um endereço de um vídeo do YouTube, irá incorporar uma antevisão na conversa
Comment[pt_BR]=Se alguma mensagem tiver um link para um vídeo do YouTube, será embutida uma visualização na conversa
Comment[ro]=Dacă vreun mesaj conține o legătură la un video YouTube, aceasta va încorpora o previzualizare în discuție
Comment[ru]=Встраивание видео с YouTube при получении ссылки на него
Comment[sk]=Ak nejaká správa obsahuje odkaz na video YouTube, budu vložený náhľad do rozhovoru
Comment[sl]=Če bo katerokoli sporočilo vsebovalo povezavo do videa YouTube, bo to vstavilo predogled v klepet
Comment[sr]=Када долазна порука садржи везу до видеа на Јутјубу, добија се угнежђени преглед унутар ћаскања
Comment[sr@ijekavian]=Када долазна порука садржи везу до видеа на Јутјубу, добија се угнијежђени преглед унутар ћаскања
Comment[sr@ijekavianlatin]=Kada dolazna poruka sadrži vezu do videa na YouTubeu, dobija se ugniježđeni pregled unutar ćaskanja
Comment[sr@latin]=Kada dolazna poruka sadrži vezu do videa na YouTubeu, dobija se ugnežđeni pregled unutar ćaskanja
Comment[sv]=Om något meddelande innehåller en länk till en video på YouTube, inbäddas en förhandsgranskning i chatten
Comment[tr]=Eğer iletilerden biri bir YouTube video bağlantısı içeriyorsa, sohbette gömülü olarak önizlemesi olacak
Comment[uk]=Якщо у будь-якому з повідомлень міститься посилання на відео на YouTube, вбудовує зображення попереднього перегляду цього відео до панелі спілкування
Comment[x-test]=xxIf any messages contains a link to a YouTube video, it will embed a preview in the chatxx
Comment[zh_CN]=如果任何消息包括到 YouTube 视频的链接，将会在聊天窗口中显示预览
Comment[zh_TW]=如果任何訊息包含到 YouTube 影像的連結，則會內嵌一個影像預覽
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_youtube
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=youtube
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

==> ktp-text-ui_19.12.3.orig.tar.xz: ktp-text-ui-19.12.3/filters/youtube/ktptextui_message_filter_youtube.desktop.cmake <==
[Desktop Entry]
Name=YouTube Preview
Name[ar]=معاينة يوتيوب
Name[bs]=YouTube pregled
Name[ca]=Vista prèvia de YouTube
Name[ca@valencia]=Vista prèvia de YouTube
Name[cs]=Náhled YouTube
Name[da]=Forhåndsvisning af YouTube
Name[de]=YouTube-Vorschau
Name[el]=Προεπισκόπηση YouTube
Name[en_GB]=YouTube Preview
Name[es]=Vista previa de YouTube
Name[et]=Youtube'i eelvaatlus
Name[eu]=YouTube aurreikuspegia
Name[fi]=YouTube-esikatselu
Name[fr]=Miniature YouTube
Name[gl]=Vista previa de YouTube
Name[hu]=YouTube előnézet
Name[ia]=Vista preliminar de YouTube
Name[it]=Anteprima di YouTube
Name[kk]=YouTube алдың-аласы
Name[ko]=YouTube 미리 보기
Name[lt]=YouTube peržiūra
Name[mr]=यूट्यूब पूर्वावलोकन
Name[nb]=YouTube forhåndsvisning
Name[nds]=YouTube-Vöransicht
Name[nl]=Voorbeeld van YouTube
Name[nn]=Førehandsvising av YouTube
Name[pa]=ਯੂਟਿਊਬ ਝਲਕ
Name[pl]=Podgląd YouTube
Name[pt]=Antevisão do YouTube
Name[pt_BR]=Visualização do YouTube
Name[ro]=Previzualizare YouTube
Name[ru]=Просмотр видео с YouTube
Name[sk]=Náhľad YouTube
Name[sl]=Predogled YouTube
Name[sr]=Преглед са Јутјуба
Name[sr@ijekavian]=Преглед са Јутјуба
Name[sr@ijekavianlatin]=Pregled sa YouTubea
Name[sr@latin]=Pregled sa YouTubea
Name[sv]=Förhandsgranskning av YouTube
Name[tr]=YouTube Önizlemesi
Name[uk]=Попередній перегляд YouTube
Name[x-test]=xxYouTube Previewxx
Name[zh_CN]=YouTube 预览
Name[zh_TW]=YouTube 預覽
Comment=If any messages contains a link to a YouTube video, it will embed a preview in the chat
Comment[ar]=إن احتوت أيّ رسالة وصلة إلى فيديو يوتيوب، ستُضمّن معاينة في الدّردشة.
Comment[bs]=Ako poruka sadrži vezu na YouTube video, oma će se ugraditi u pregled ćaskanja
Comment[ca]=Si qualsevol missatge conté un enllaç a un vídeo de YouTube, s'incrustarà una vista prèvia en el xat
Comment[ca@valencia]=Si qualsevol missatge conté un enllaç a un vídeo de YouTube, s'incrustarà una vista prèvia en el xat
Comment[cs]=Pokud zpráva obsahuje odkaz na video YouTube bude vložen jeho náhled do rozhovoru
Comment[da]=If beskeder indeholder et link til en YouTube-video vil en forhåndsvisning blive indlejret i chatten
Comment[de]=Wenn eine Nachricht eine Verknüpfung zu einem YouTube-Video enthält, wird das Video als Vorschau im Chat-Fenster angezeigt
Comment[el]=Στα μηνύματα που περιέχουν σύνδεσμο σε YouTube βίντεο, θα ενσωματώνεται η προεπισκόπηση στη συνομιλία
Comment[en_GB]=If any messages contains a link to a YouTube video, it will embed a preview in the chat
Comment[es]=Si un mensaje contiene un enlace a un vídeo de YouTube, esta opción incrustará una vista previa en la conversación.
Comment[et]=Kui sisenev sõnum sisaldab Youtube'i video linki, põimitakse selle eelvaatlus vestlusse
Comment[eu]=Youtube bideoren baten esteka duen mezurik balego, berriketan aurreikuspegi bat txertatuko litzateke
Comment[fi]=Jos saapuvassa viestissä on linkki YouTube-videoon, keskusteluun upotetaan esikatselu videosta
Comment[fr]=Si un quelconque message contient un lien vers une vidéo YouTube, il intégrera une miniature dans la conversation
Comment[gl]=Se algunha mensaxe contén unha ligazón a un vídeo en YouTube ha incluír unha vista previa na conversa
Comment[hu]=Ha egy üzenet hivatkozást tartalmaz egy YouTube videóra, akkor az előnézet be lesz ágyazva a csevegésbe
Comment[ia]=Si qualcunque messages contine un ligamine a tu video de YouTube, illlo incorporara un vista preliminar in le conversation.
Comment[it]=Se in un messaggio c'è un collegamento ad un video di YouTube, sarà integrato come anteprima nella finestra di chat
Comment[kk]=Егер хабарламада YouTube видеосына сілтеме болса, оның қарап-шығу мүмкіндігі чатта болады
Comment[ko]=YouTube 동영상 링크를 포함하는 경우 대화 창에 미리 보기를 표시
Comment[lt]=Jei bet kuri žinutė turi nuorodą į YouTube vaizdo įrašą, bus įterpta peržiūra pokalbyje
Comment[nb]=Hvis en melding inneholder en lenke til en YouTube-video, så blir en forhåndsvisning av videoen bygget inn i praten
Comment[nds]=För elkeen binnen en Naricht vörhannen Link op en YouTube-Video en Vöransicht inbetten
Comment[nl]=Als een bericht een koppeling bevat naar een YouTube video, zal het ingebed worden als een voorbeeld in de chat
Comment[nn]=Viss ei melding inneheld ei lenkje til ein YouTube-video, vert ei førehandsvising innebygd i praten
Comment[pl]=Jeśli jakakolwiek wiadomość zawiera odnośnik do filmu na YouTube, to zostanie osadzony jej podgląd w oknie rozmowy
Comment[pt]=Se alguma das mensagens tiver um endereço de um vídeo do YouTube, irá incorporar uma antevisão na conversa
Comment[pt_BR]=Se alguma mensagem tiver um link para um vídeo do YouTube, será embutida uma visualização na conversa
Comment[ro]=Dacă vreun mesaj conține o legătură la un video YouTube, aceasta va încorpora o previzualizare în discuție
Comment[ru]=Встраивание видео с YouTube при получении ссылки на него
Comment[sk]=Ak nejaká správa obsahuje odkaz na video YouTube, budu vložený náhľad do rozhovoru
Comment[sl]=Če bo katerokoli sporočilo vsebovalo povezavo do videa YouTube, bo to vstavilo predogled v klepet
Comment[sr]=Када долазна порука садржи везу до видеа на Јутјубу, добија се угнежђени преглед унутар ћаскања
Comment[sr@ijekavian]=Када долазна порука садржи везу до видеа на Јутјубу, добија се угнијежђени преглед унутар ћаскања
Comment[sr@ijekavianlatin]=Kada dolazna poruka sadrži vezu do videa na YouTubeu, dobija se ugniježđeni pregled unutar ćaskanja
Comment[sr@latin]=Kada dolazna poruka sadrži vezu do videa na YouTubeu, dobija se ugnežđeni pregled unutar ćaskanja
Comment[sv]=Om något meddelande innehåller en länk till en video på YouTube, inbäddas en förhandsgranskning i chatten
Comment[tr]=Eğer iletilerden biri bir YouTube video bağlantısı içeriyorsa, sohbette gömülü olarak önizlemesi olacak
Comment[uk]=Якщо у будь-якому з повідомлень міститься посилання на відео на YouTube, вбудовує зображення попереднього перегляду цього відео до панелі спілкування
Comment[x-test]=xxIf any messages contains a link to a YouTube video, it will embed a preview in the chatxx
Comment[zh_CN]=如果任何消息包括到 YouTube 视频的链接，将会在聊天窗口中显示预览
Comment[zh_TW]=如果任何訊息包含到 YouTube 影像的連結，則會內嵌一個影像預覽
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_youtube
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=youtube
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@
